﻿#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -*- Python -*-

"""
 @file GRobotPoseMaker.py
 @brief Make GRobot Pose
 @date $Date$


"""
import sys
import time
import math
sys.path.append(".")

# Import RTM module
import RTC
import OpenRTM_aist


# Import Service implementation class
# <rtc-template block="service_impl">

# </rtc-template>

# Import Service stub modules
# <rtc-template block="consumer_import">
# </rtc-template>


# This module's spesification
# <rtc-template block="module_spec">
grobotposemaker_spec = ["implementation_id", "GRobotPoseMaker", 
		 "type_name",         "GRobotPoseMaker", 
		 "description",       "Make GRobot Pose", 
		 "version",           "1.0.0", 
		 "vendor",            "Yuya Tatsuta", 
		 "category",          "Category", 
		 "activity_type",     "STATIC", 
		 "max_instance",      "1", 
		 "language",          "Python", 
		 "lang_type",         "SCRIPT",
		 ""]
# </rtc-template>

##
# @class GRobotPoseMaker
# @brief Make GRobot Pose
# 
# 
class GRobotPoseMaker(OpenRTM_aist.DataFlowComponentBase):
	
	##
	# @brief constructor
	# @param manager Maneger Object
	# 
	def __init__(self, manager):
		OpenRTM_aist.DataFlowComponentBase.__init__(self, manager)

		self._d_InTrigger = OpenRTM_aist.instantiateDataType(RTC.TimedLong)
		"""
		You want to make G-Robot special pose, you trigger this port.
		If this port is 0, G-Robot pose basic pose.
		"""
		self._InTriggerIn = OpenRTM_aist.InPort("InTrigger", self._d_InTrigger)
		self._d_PoseType = OpenRTM_aist.instantiateDataType(RTC.TimedLong)
		"""
		You choose special pose type.
		"""
		self._PoseTypeIn = OpenRTM_aist.InPort("PoseType", self._d_PoseType)
		self._d_GRobotPose = OpenRTM_aist.instantiateDataType(RTC.TimedDoubleSeq)
		"""
		"""
		self._GRobotPoseOut = OpenRTM_aist.OutPort("GRobotPose", self._d_GRobotPose)


		


		# initialize of configuration-data.
		# <rtc-template block="init_conf_param">
		
		# </rtc-template>


		 
	##
	#
	# The initialize action (on CREATED->ALIVE transition)
	# formaer rtc_init_entry() 
	# 
	# @return RTC::ReturnCode_t
	# 
	#
	def onInitialize(self):
		# Bind variables and configuration variable
		
		# Set InPort buffers
		self.addInPort("InTrigger",self._InTriggerIn)
		self.addInPort("PoseType",self._PoseTypeIn)
		
		# Set OutPort buffers
		self.addOutPort("GRobotPose",self._GRobotPoseOut)
		
		# Set base pose, spacial pose
		self.base_pose = [0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0]
		
		# Set service provider to Ports
		
		# Set service consumers to Ports
		
		# Set CORBA Service Ports
		
		return RTC.RTC_OK
	
	###
	## 
	## The finalize action (on ALIVE->END transition)
	## formaer rtc_exiting_entry()
	## 
	## @return RTC::ReturnCode_t
	#
	## 
	#def onFinalize(self):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The startup action when ExecutionContext startup
	## former rtc_starting_entry()
	## 
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##
	##
	#def onStartup(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The shutdown action when ExecutionContext stop
	## former rtc_stopping_entry()
	##
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##
	##
	#def onShutdown(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The activated action (Active state entry action)
	## former rtc_active_entry()
	##
	## @param ec_id target ExecutionContext Id
	## 
	## @return RTC::ReturnCode_t
	##
	##
	#def onActivated(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The deactivated action (Active state exit action)
	## former rtc_active_exit()
	##
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##
	##
	#def onDeactivated(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	##
	#
	# The execution action that is invoked periodically
	# former rtc_active_do()
	#
	# @param ec_id target ExecutionContext Id
	#
	# @return RTC::ReturnCode_t
	#
	#
	
	def onExecute(self, ec_id):
		Trigger = self._InTriggerIn.read().data
		if(Trigger == 0):
			pose = self.base_pose
			print("Basic Pose")
		else:
			PoseType = self._PoseTypeIn.read().data
			
			# Summer Camp デバッグ用出力
			if PoseType == 1:
				print("グー")
				pose = [0.0,0.0,math.radians(-90.0),0.0,0.0,math.radians(90.0),0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0]
			if PoseType == 2:
				print("パー")
				pose = [0.0,0.0,math.radians(-90.0),math.radians(-90.0),math.radians(130.0),math.radians(90.0),math.radians(90.0),math.radians(-130.0),0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0]
			if PoseType == 3:
				print("チョキ")
				pose = [0.0,0.0,math.radians(-150.0),math.radians(-40.0),0.0,0.0,math.radians(150),math.radians(40.0),0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0]
		self._d_GRobotPose.data = pose
		self._GRobotPoseOut.write()
		return RTC.RTC_OK
	
	###
	##
	## The aborting action when main logic error occurred.
	## former rtc_aborting_entry()
	##
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##
	##
	#def onAborting(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The error action in ERROR state
	## former rtc_error_do()
	##
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##
	##
	#def onError(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The reset action that is invoked resetting
	## This is same but different the former rtc_init_entry()
	##
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##
	##
	#def onReset(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The state update action that is invoked after onExecute() action
	## no corresponding operation exists in OpenRTm-aist-0.2.0
	##
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##

	##
	#def onStateUpdate(self, ec_id):
	#
	#	return RTC.RTC_OK
	
	###
	##
	## The action that is invoked when execution context's rate is changed
	## no corresponding operation exists in OpenRTm-aist-0.2.0
	##
	## @param ec_id target ExecutionContext Id
	##
	## @return RTC::ReturnCode_t
	##
	##
	#def onRateChanged(self, ec_id):
	#
	#	return RTC.RTC_OK
	



def GRobotPoseMakerInit(manager):
    profile = OpenRTM_aist.Properties(defaults_str=grobotposemaker_spec)
    manager.registerFactory(profile,
                            GRobotPoseMaker,
                            OpenRTM_aist.Delete)

def MyModuleInit(manager):
    GRobotPoseMakerInit(manager)

    # Create a component
    comp = manager.createComponent("GRobotPoseMaker")

def main():
	mgr = OpenRTM_aist.Manager.init(sys.argv)
	mgr.setModuleInitProc(MyModuleInit)
	mgr.activateManager()
	mgr.runManager()

if __name__ == "__main__":
	main()

